@@ -1,5 +1,11 @@
+# Like what you see? Join us!
+# https://www.univention.com/about-us/careers/vacancies/
+#
+# SPDX-FileCopyrightText: 2024 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
+
 """UCS Test errors."""
-__all__ = ['TestError', 'TestConditionError']
+__all__ = ['TestConditionError', 'TestError']
 
 
 class TestError(Exception):
